@@ -4,12 +4,14 @@ import ast
 import contextlib
 import errno
 import fcntl
+import inspect
 import os
 import queue
 import select
 import sys
 import tempfile
 import textwrap
+from enum import Enum
 from functools import partial
 from pathlib import Path
 from queue import Queue
@@ -597,6 +599,12 @@ class DynamicButton(QWidget):
         return f"DynamicButton(\"{self.label}\", {self.function})"
 
 
+def combo_box_from_enum(enumeration: Enum):
+    cb = QComboBox()
+    cb.addItems([x.name for x in enumeration])
+    return cb
+
+
 class ArgumentsPanel(QScrollArea):
     def __init__(self, button: DynamicButton, ui_args: Dict[str, Argument]):
         super().__init__()
@@ -604,26 +612,28 @@ class ArgumentsPanel(QScrollArea):
         self.setWidgetResizable(True)
 
         widget = QWidget()
+
+        widget.setStyleSheet(textwrap.dedent(
+            """
+                QGroupBox {
+                    font-size: 16px;
+                    font-weight: light;
+                    color: grey;
+                    /* margin-top: 25px; */
+                }
+                QGroupBox::title {
+                    subcontrol-origin: margin;
+                    subcontrol-position: top left;
+                    left: 10px;
+                    /* padding-top: 5px; */
+                    /* padding-bottom: 0px */
+                }
+            """)
+        )
+
         main_layout = QHBoxLayout()
 
         self.group_box = QGroupBox(f"arguments for '{button.function_display_name}'")
-        self.group_box.setStyleSheet(
-            textwrap.dedent(
-                """
-                    QGroupBox {
-                        font-size: 14px;
-                        font-weight: light;
-                        color: grey;
-                        margin-top: 25px;
-                    }
-                    QGroupBox::title {
-                        subcontrol-origin: margin;
-                        left: 10px;
-                        padding-top: 5px;
-                        padding-bottom: 0px
-                    }
-                """)
-        )
 
         self._button = button
         self._ui_args = ui_args
@@ -642,6 +652,8 @@ class ArgumentsPanel(QScrollArea):
                 input_field.setCheckState(Qt.Checked if arg.default else Qt.Unchecked)
             elif isinstance(arg.annotation, TypeObject):
                 input_field: QWidget = arg.annotation.get_widget()
+            elif inspect.isclass(arg.annotation) and issubclass(arg.annotation, Enum):
+                input_field = combo_box_from_enum(arg.annotation)
             else:
                 input_field = QLineEdit()
                 input_field.setObjectName(name)
@@ -720,6 +732,7 @@ class ArgumentsPanel(QScrollArea):
         hbox.addStretch()
         hbox.addWidget(self.run_button)
 
+        vbox.addStretch()
         vbox.addLayout(hbox)
 
         self.group_box.setLayout(vbox)
@@ -778,13 +791,15 @@ class ArgumentsPanel(QScrollArea):
             self.script_rb.setChecked(True)
             return RUNNABLE_SCRIPT
 
-    def _cast_arg(self, name: str, field: QLineEdit | QCheckBox | UQWidget):
+    def _cast_arg(self, name: str, field: QLineEdit | QCheckBox | QComboBox | UQWidget):
         arg = self._ui_args[name]
 
         if arg.annotation is bool:
             return field.checkState() == Qt.Checked
         elif isinstance(arg.annotation, TypeObject):
             return field.get_value()
+        elif inspect.isclass(arg.annotation) and issubclass(arg.annotation, Enum):
+            return arg.annotation[field.currentText()]
         else:
 
             if not (value := field.displayText() or field.placeholderText()):
